@@ -153,12 +153,18 @@ cat(format(a, digits=4))
 # cat(format(a, use.names=FALSE))
 cat(format(a, style="pmax"))
 cat(format(a, use.names=FALSE, style="p"))
+a <- earth(Volume ~ Girth*Height, data = trees, pmethod="none")
+cat(format(a))
+cat(format(a, valid.names=TRUE))
 a <- lm(Volume ~ ., data = trees)
 cat(format(a)) # basic tests of format.lm
 cat(format(a, digits=4))
 cat(format(a, use.names=FALSE))
 cat(format(a, style="p"))
 cat(format(a, use.names=FALSE, style="p"))
+a <- lm(Volume ~ Girth*Height, data = trees)
+cat(format(a))
+cat(format(a, valid.names=TRUE))
 cat("--- mars.to.earth.Rd ----------------------\n")
 example(mars.to.earth) # doesn't do anything
 library(mda)
